Lua_GodSeaPeakHonourPanel = class("Lua_GodSeaPeakHonourPanel", Lua_DisplayObject)
function Lua_GodSeaPeakHonourPanel:ctor(p)
	self:superCall("ctor", p, "GodSeaPeakHonourPanel_skin");
end

function Lua_GodSeaPeakHonourPanel:buildShowItem()
	self:superCall("buildShowItem");
	self.topThreeList = Array();
	local posDic = {{-8, -42}, {-235, -29}, {220, -29}};
	local item;
	for i = 1, 3 do
		item = Lua_GodSeaPeakHonourModelItem.new(self.content);
		item:setLocation(posDic[i][1], posDic[i][2], 0);
		item:setData(i, nil);
		self.topThreeList:add(item);
	end

	self.btnLeft:addClickFuntion(self, self.onLeftClick);
	self.btnRight:addClickFuntion(self, self.onRightClick);

	self:addLuaEvent("GOD_SEA_PEAK_HONOUR_INFO", self, self.updateShowInfo);
	self:addLuaEvent("GOD_SEA_PEAK_SEASON_INFO", self, self.updateTopThree);
	Lua_ProxyManager.getProxy("Lua_GodSeaPeakProxy"):sHonourInfo();
end

function Lua_GodSeaPeakHonourPanel:dispose()
	if self.topThreeList then
		self.topThreeList:dispose();
		self.topThreeList:clear();
		self.topThreeList = nil;
	end
	self:superCall("dispose");
end

function Lua_GodSeaPeakHonourPanel:updateShowInfo(msg)
	table.sort( msg.season_list, function(a, b) return tonumber(a.value) < tonumber(b.value) end);
	self.seasonList = msg.season_list;
	self.seasonLen = #msg.season_list;
	self.curSeasonIdx = self.seasonLen;
	self:updateSeason();

	self.curRankText.text = LanUtil.formateStr(790023, tostring(msg.ranking));
	if msg.history_ranking <= 0 then
		self.hisRankText:setLangValue(790024);
	else
		self.hisRankText.text = LanUtil.formateStr(790025, tostring(msg.history_ranking));
	end
end

function Lua_GodSeaPeakHonourPanel:updateSeason()
	local data = self.seasonList[self.curSeasonIdx];
	if data == nil then
		self.timeBg:setEnable(false);
		self.timeText:setEnable(false);
	else
		self.timeBg:setEnable(true);
		
		local startStr = os.date(LanUtil.getValue(57), data.value);
		local endStr = os.date(LanUtil.getValue(57), data.ex_value);
		self.timeText:setEnable(true);
		self.timeText.text = LanUtil.formateStr(10052, startStr, endStr);
		Lua_ProxyManager.getProxy("Lua_GodSeaPeakProxy"):sSeasonInfo(data.key);
	end

	if self.curSeasonIdx <= 1 then
		self.btnLeft:setEnable(false);
	else
		self.btnLeft:setEnable(true);
	end
	if self.curSeasonIdx >= self.seasonLen then
		self.btnRight:setEnable(false);
	else
		self.btnRight:setEnable(self.seasonLen > 1);
	end
end

function Lua_GodSeaPeakHonourPanel:updateTopThree(msg)
	local list = msg.celebrity_list;
	for i = 1, 3 do
		if list == nil or #list < i then
			self.topThreeList[i]:setData(i, nil, self.curSeasonIdx == self.seasonLen);
		else
			self.topThreeList[i]:setData(i, list[i], self.curSeasonIdx == self.seasonLen);
		end
	end
end

function Lua_GodSeaPeakHonourPanel:onLeftClick(go)
	if self.clickTime and getTime() - self.clickTime < 0.3 then
		return;
	end
	self.clickTime = getTime();

	self.curSeasonIdx = self.curSeasonIdx - 1;
	self:updateSeason();
end

function Lua_GodSeaPeakHonourPanel:onRightClick(go)
	if self.clickTime and getTime() - self.clickTime < 0.3 then
		return;
	end
	self.clickTime = getTime();

	self.curSeasonIdx = self.curSeasonIdx + 1;
	self:updateSeason();
end










Lua_GodSeaPeakHonourModelItem = class("Lua_GodSeaPeakHonourModelItem", Lua_DisplayObject)
function Lua_GodSeaPeakHonourModelItem:ctor(p)
	self:superCall("ctor", p, "GodSeaPeakHonourModelItem_skin");
end

function Lua_GodSeaPeakHonourModelItem:buildShowItem()
	self:superCall("buildShowItem");
	self:addLuaEvent("PEAK_DUEL_RANK_UPDATE", self, self.updateData)
	self.btnLike:addClickFuntion(self, self.onLikeClick);
	self.clickArea:addClickFuntion(self, self.onClick);
end

function Lua_GodSeaPeakHonourModelItem:dispose()
	if self.redPoint then
		self.redPoint:dispose();
		self.redPoint = nil;
	end
	self.data = nil;
	self:superCall("dispose")
end

function Lua_GodSeaPeakHonourModelItem:setData(rank, data, canLike)
	self.data = data;
	self.canLike = canLike;

	if rank == 1 then
		self.titleIcon:setAltas("role_title_1", "304000014");
		self.titleIcon:setLocation(0, 430, 0);
		self.rankIcon:setAltas("championship_1", "xui_jys_label_17");
		self.clickArea:SetDimensions(200, 360);
		self.clickArea:setLocation(0, 225, 0);
	elseif rank == 2 then
		self.titleIcon:setAltas("role_title_1", "304000015");
		self.titleIcon:setLocation(0, 380, 0);
		self.rankIcon:setAltas("championship_1", "xui_jys_label_18");
		self.clickArea:SetDimensions(200, 330);
		self.clickArea:setLocation(0, 200, 0);
	else
		self.titleIcon:setAltas("role_title_1", "304000016");
		self.titleIcon:setLocation(0, 380, 0);
		self.rankIcon:setAltas("championship_1", "xui_jys_label_19");
		self.clickArea:SetDimensions(200, 330);
		self.clickArea:setLocation(0, 200, 0);
	end

	self:updateData();
end

function Lua_GodSeaPeakHonourModelItem:updateData(msg)
	if self.data == nil then
		self.nameText:setLangValue(540016);
		self.btnLike:setEnable(false);
		self.likeCount:setEnable(false);
	else
		if msg and msg.role_info and msg.role_info.role_id == self.data.role_id then
			self.data = msg.role_info;
		end
		self.nameText.text = self.data.show_role.name;
		self.btnLike:setEnable(self.canLike);
		self.likeCount:setEnable(self.canLike);
		self.likeCount.text = self.data.praised_num;
	end
end

function Lua_GodSeaPeakHonourModelItem:onLikeClick(go)
	if self.data == nil then
		return;
	end
	if self.data.is_praised == 1 then
		OperateAlert.showLangValue(540045);
		return;
	end
	Lua_ProxyManager.getProxy("Lua_GodSeaPeakProxy"):sLike(self.data.role_id, 2);
end

function Lua_GodSeaPeakHonourModelItem:onClick(go)
	if self.data == nil then
		return;
	end
	if self.data.is_robot == 1 then
		OperateAlert.showLangValue(123657);
		return;
	end
	if DataCenter.roleData:isMyself(self.data.show_role.id) then
		OperateAlert.showLangValue(123656);
		return;
	end
	Lua_ProxyManager.getProxy("Lua_RoleProxy"):sOtherRoleId(self.data.show_role.id, self.data.show_role.server_flag);
end