Lua_GodSeaPeakEnemyWindow = class("Lua_GodSeaPeakEnemyWindow", Lua_Window)
function Lua_GodSeaPeakEnemyWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_GodSeaPeakEnemyWindow";
	self.skinName = "GodSeaPeakEnemyWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_GodSeaPeakEnemyWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.itemList = Array();

	self.avatarItem = Lua_AvatarItem.new(self.content);
	self.avatarItem:setScale(0.9, 0.9, 1);
	self.avatarItem:setLocation(-243, 239, 0);

	self.forceNum = Lua_NumberImage.new(self.content);
	self.forceNum:setLocation(158, 147, 0);
	self.forceNum.pivot = 1;
	self.forceNum.scaleVal = 0.9;
	self.forceNum.numOffsetX = -2;
	self.forceNum.numAtlas = "number";
	self.forceNum.preStr = "xui_zl1_number_0";

	self:addLuaEvent("GOD_SEA_PEAK_CHECK_LINEUP", self, self.updateEnemyLineup);
end

function Lua_GodSeaPeakEnemyWindow:dispose()
	if self.avatarItem then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end
	if self.forceNum then
		self.forceNum:dispose();
		self.forceNum = nil;
	end
	if self.itemList then
		self.itemList:dispose();
		self.itemList = nil;
	end
	self:superCall("dispose");
end

function Lua_GodSeaPeakEnemyWindow:showWin(param)
	self:superCall("showWin", param);
	Lua_ProxyManager.getProxy("Lua_GodSeaPeakProxy"):sCheckLineup(param.show_role.id);

	self.avatarItem:setRoleDressUp(param.show_role.dress_info);
	self.nameText.text = param.show_role.name;
	if param.is_robot == 1 then
		self.serverText.text = LanUtil.formateStr(790018, DataCenter.roleData.server_prev);
	else
		self.serverText.text = LanUtil.formateStr(790018, param.show_role.server_prev);
	end
	if strIsNullOrEmpty(param.show_role.league_name) then
		self.leagueText.text = LanUtil.formateStr(790019, LanUtil.getValue(20));
	else
		self.leagueText.text = LanUtil.formateStr(790019, param.show_role.league_name);
	end
end

function Lua_GodSeaPeakEnemyWindow:updateEnemyLineup(msg)
	local hideDic = {};
	for i,v in ipairs(msg.shield_index) do
		hideDic[v] = 1;
	end

	local len = #msg.lineup;
	local item;
	local force = 0;
	for i = 1, 3 do
		item = self.itemList[i];
		if item == nil then
			item = Lua_GodSeaPeakEnemyItem.new(self.content);
			self.itemList:add(item);
		end
		item:setLocation(3, 36 - (i - 1) * 165, 0);
		if i <= len then
			item:setData(i, msg.lineup[i], hideDic[i] == 1);
		else
			item:setData(i, nil, hideDic[i] == 1);
		end
		if msg.lineup[i] then
			force = force + msg.lineup[i].force;
		end
	end
	self.forceNum.num = force;
end










Lua_GodSeaPeakEnemyItem = class("Lua_GodSeaPeakEnemyItem", Lua_DisplayObject)
function Lua_GodSeaPeakEnemyItem:ctor(p)
	self:superCall("ctor", p, "GodSeaPeakEnemyItem_skin");
end

function Lua_GodSeaPeakEnemyItem:buildShowItem()
	self:superCall("buildShowItem");
	self.heroList = Array();
	self.dataList = Array();
end

function Lua_GodSeaPeakEnemyItem:dispose()
	if self.heroList then
		self.heroList:dispose();
		self.heroList:clear();
		self.heroList = nil;
	end
	if self.dataList then
		self.dataList:clear();
		self.dataList = nil;
	end
	self:superCall("dispose");
end

function Lua_GodSeaPeakEnemyItem:setData(idx, data, isHide)
	self.titleText.text = LanUtil.formateStr(790020, tostring(idx));

	local arr = Array();
	if isHide then
		self.forceText:setLangValue(790030);
	else
		if data == nil then
			self.forceText.text = 0;
		else
			self.forceText.text = data.force;
			for i = 1, #data.hero_list do
				if tonumber(data.hero_list[i].hero_id) > 0 then
					arr:add(data.hero_list[i]);
				end
			end
		end
	end

	local num = idx * 2;
	local len = self.heroList:getSize();
	local maxLen = num > len and num or len;
	local item, vo;
	for i = 1, maxLen do
		item = self.heroList[i];
		if i > num then
			if item then
				item:setEnable(false);
			end
		else
			if item == nil then
				item = Lua_ItemIcon.new(self.content);
				item:setScale(0.7, 0.7, 1);
				self.heroList:add(item);
			else
				item:setEnable(true);
			end
			item:setLocation(-235 + (i - 1) * 95, -17, 0);

			if isHide then
				item:setClick(self, self.onClick);
				item:setData(nil);
				item:setShadow(isHide, "god_sea_peak_atlas_1", "xui_shzd_widget_12");
			else
				item:setClick(nil, nil);
				item:setCanClick(true);
				item:setShadow(false);
				if arr[i] == nil then
					item:setData(nil);
				else
					vo = self.dataList[i];
					if vo == nil then
						vo = Lua_HeroVo.new(arr[i].hero_id);
						self.dataList:add(vo);
					else
						vo:setData(arr[i].hero_id);
					end
					vo:fromServer(arr[i]);
					item:setData(vo);
				end
			end
		end
	end
end

function Lua_GodSeaPeakEnemyItem:onClick()
	OperateAlert.showLangValue(790034);
end