Lua_GodSeaPeakFightWindow = class("Lua_GodSeaPeakFightWindow", Lua_Window)
function Lua_GodSeaPeakFightWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_GodSeaPeakFightWindow";
	self.skinName = "GodSeaPeakFightWindow_skin";
	self.isFullSizeWin = true;
	self.showBlackMask = true;
	self.showBackBtn = true;
end

function Lua_GodSeaPeakFightWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.defendList = Array();
	self.attackList = Array();

	self.uiEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_shzd_dj", "ui_shzd_dj", 0, 0);
	self.uiEff.siblingIndex = 3;

	self.defengAavatar = Lua_AvatarItem.new(self.content);
	self.defengAavatar:setScale(0.5, 0.5, 1);
	self.defengAavatar:setLocation(320, 72, 0);

	self.attackAavatar = Lua_AvatarItem.new(self.content);
	self.attackAavatar:setScale(0.5, 0.5, 1);
	self.attackAavatar:setLocation(-324, 72, 0);
	self.attackAavatar:setRoleDressUp(DataCenter.roleData.dress_info);

	self.attackNameText.text = DataCenter.roleData.name;
	self.btnFight:addClickFuntion(self, self.onFightClick);
	self.cbSkip.selected = DataCenter.godSeaPeakData.isSkip;
	self.cbSkip:addBoxChange(self, self.onSkipChange);

	self:addLuaEvent("GOD_SEA_PEAK_CHECK_LINEUP", self, self.updateEnemyLineup);
	self:addLuaEvent("UPDATE_HERO_LINEUP_INFO", self, self.onLineupInfoUpdate);
	self:addLuaEvent("GOD_SEA_PEAK_LINEUP", self, self.onLineupEdit);
	self:onLineupInfoUpdate();
end

function Lua_GodSeaPeakFightWindow:dispose()
	DataCenter.preLoadData:removeBySign("Lua_GodSeaPeakLineupWindow", self, self.onSceneShow);
	if self.uiEff then
		self.uiEff:dispose();
		self.uiEff = nil;
	end
	if self.defengAavatar then
		self.defengAavatar:dispose();
		self.defengAavatar = nil;
	end
	if self.attackAavatar then
		self.attackAavatar:dispose();
		self.attackAavatar = nil;
	end
	if self.defendList then
		self.defendList:dispose();
		self.defendList = nil;
	end
	if self.attackList then
		self.attackList:dispose();
		self.attackList = nil;
	end
	self:superCall("dispose");
end

function Lua_GodSeaPeakFightWindow:showWin(param)
	self:superCall("showWin", param);
	Lua_ProxyManager.getProxy("Lua_GodSeaPeakProxy"):sCheckLineup(param.show_role.id);

	self.defengAavatar:setRoleDressUp(param.show_role.dress_info);
	if param.is_robot == 1 then
		self.defendNameText.text = param.show_role.name;
	else
		self.defendNameText.text = LanUtil.formateStr(10051, param.show_role.server_prev, param.show_role.name);
	end
end

function Lua_GodSeaPeakFightWindow:updateEnemyLineup(msg)
	local hideDic = {};
	for i,v in ipairs(msg.shield_index) do
		hideDic[v] = 1;
	end

	local len = #msg.lineup;
	local item;
	for i = 1, 3 do
		item = self.defendList[i];
		if item == nil then
			item = Lua_GodSeaPeakFightDefendItem.new(self.content);
			self.defendList:add(item);
		end
		if i == 1 then
			item:setLocation(-241, 195, 0);
		elseif i == 3 then
			item:setLocation(241, 144, 0);
		else
			item:setLocation(0, 167, 0);
		end
		if i <= len then
			item:setData(i, msg.lineup[i], hideDic[i] == 1);
		else
			item:setData(i, nil, hideDic[i] == 1);
		end
	end
end

function Lua_GodSeaPeakFightWindow:onLineupInfoUpdate(lineupType)
	local vo = DataCenter.heroLineupData:getLineupVo(59);
	local item;
	for i = 1, 3 do
		item = self.attackList[i];
		if item == nil then
			item = Lua_GodSeaPeakFightAttackItem.new(self.content);
			self.attackList:add(item);
		end
		if i == 1 then
			item:setLocation(-241, 10, 0);
		elseif i == 3 then
			item:setLocation(241, -40, 0);
		else
			item:setLocation(0, -16, 0);
		end
		item:setData(i, vo:getHeroArr(i));
	end
end

function Lua_GodSeaPeakFightWindow:onLineupEdit(idx)
	local sceneId = DataCenter.heroLineupData:getFightLineupSceneId(Lua_FightDefine.TEMPLATE_ID_GODSEAPEAK);
	DataCenter.preLoadData:preShowScene("Lua_GodSeaPeakLineupWindow", Lua_PreLoadDefine.LOADSHOW_TYPE_NONE, self, self.onSceneShow, idx, sceneId, 0);
end

function Lua_GodSeaPeakFightWindow:onSceneShow(param, mp, success)
	if not success then return; end
	Lua_WindowUtil.openWin("Lua_GodSeaPeakLineupWindow", Lua_WinParam.ACTION_OPEN, { lineupType = 59, lineupIdx = param });
end

function Lua_GodSeaPeakFightWindow:onFightClick(go)
	if DataCenter.godSeaPeakData.acquiredState == 1 then
		OperateAlert.showLangValue(790043);
		return;
	end
	if DataCenter.heroLineupData:checkLineupIsNull(59) then
		OperateAlert.showLangValue(790026);
		return;
	end
	Lua_ProxyManager.getProxy("Lua_FightProxy"):sStartFight(Lua_FightDefine.TEMPLATE_ID_GODSEAPEAK, 0, self.showData.show_role.id);
end

function Lua_GodSeaPeakFightWindow:onSkipChange(bChange)
	local limitTimes = DataCenter.godSeaPeakUtil.skipFightTimes;
	if DataCenter.godSeaPeakData.winTimes < limitTimes then
		OperateAlert.show(LanUtil.formateStr(790029, tostring(limitTimes)));
		self.cbSkip.selected = false;
		return;
	end

	self.cbSkip.selected = bChange;
	Lua_ProxyManager.getProxy("Lua_GodSeaPeakProxy"):sSkipFight(bChange and 1 or 0);
end










Lua_GodSeaPeakFightDefendItem = class("Lua_GodSeaPeakFightDefendItem", Lua_DisplayObject)
function Lua_GodSeaPeakFightDefendItem:ctor(p)
	self:superCall("ctor", p, "GodSeaPeakFightDefendItem_skin");
end

function Lua_GodSeaPeakFightDefendItem:buildShowItem()
	self:superCall("buildShowItem");
	self.heroList = Array();
	self.dataList = Array();

	self.forceNum = Lua_NumberImage.new(self.content);
	self.forceNum:setLocation(-70, 0, 0);
	self.forceNum.pivot = 1;
	self.forceNum.scaleVal = 0.9;
	self.forceNum.numOffsetX = -2;
	self.forceNum.numAtlas = "number";
	self.forceNum.preStr = "xui_zl1_number_0";
end

function Lua_GodSeaPeakFightDefendItem:dispose()
	if self.heroList then
		self.heroList:dispose();
		self.heroList:clear();
		self.heroList = nil;
	end
	if self.dataList then
		self.dataList:clear();
		self.dataList = nil;
	end
	if self.forceNum then
		self.forceNum:dispose();
		self.forceNum = nil;
	end
	self:superCall("dispose");
end

function Lua_GodSeaPeakFightDefendItem:setData(idx, data, isHide)
	self.numText.text = idx;

	local arr = Array();
	if data and not isHide then
		for i = 1, #data.hero_list do
			if tonumber(data.hero_list[i].hero_id) > 0 then
				arr:add(data.hero_list[i]);
			end
		end
	end

	local num = idx * 2;
	local len = self.heroList:getSize();
	local maxLen = num > len and num or len;
	local item, vo;
	local force = 0;
	for i = 1, maxLen do
		item = self.heroList[i];
		if i > num then
			if item then
				item:setEnable(false);
			end
		else
			if item == nil then
				item = Lua_ItemIcon.new(self.content);
				self.heroList:add(item);
			else
				item:setEnable(true);
			end
			if num == 2 then
				item:setLocation(-35 + (i - 1) * 65, 98, 0);
			elseif num == 4 then
				if i == 1 then
					item:setLocation(0, 130.5, 0);
				else
					item:setLocation(-130 + (i - 1) * 65, 62.5, 0);
				end
			else
				if i < 4 then
					item:setLocation(-65 + (i - 1) * 65, 130.5, 0);
				else
					item:setLocation(-260 + (i - 1) * 65, 62.5, 0);
				end
			end

			if isHide then
				item:setClick(self, self.onClick);
				item:setScale(1, 1, 1);
				item:setData(nil);
				item:setIconBg("god_sea_peak_atlas_1", "xui_shzd_widget_31");
				item:setShadow(isHide, "god_sea_peak_atlas_1", "xui_dfs_label_4", 0.5);
			else
				item:setClick(nil, nil);
				item:setCanClick(true);
				item:setScale(0.5, 0.5, 1);
				item:setShadow(false);
				if arr[i] == nil then
					item:setData(nil);
				else
					vo = self.dataList[i];
					if vo == nil then
						vo = Lua_HeroVo.new(arr[i].hero_id);
						self.dataList:add(vo);
					else
						vo:setData(arr[i].hero_id);
					end
					vo:fromServer(arr[i]);
					item:setData(vo);
					force = force + vo.heroForce;
				end
			end
		end
	end
	if isHide then
		self.hideObject:SetActive(true);
		self.forceNum:setEnable(false);
	else
		self.hideObject:SetActive(false);
		self.forceNum:setEnable(true);
		self.forceNum.num = force;
	end
end

function Lua_GodSeaPeakFightDefendItem:onClick()
	OperateAlert.showLangValue(790034);
end










Lua_GodSeaPeakFightAttackItem = class("Lua_GodSeaPeakFightAttackItem", Lua_DisplayObject)
function Lua_GodSeaPeakFightAttackItem:ctor(p)
	self:superCall("ctor", p, "GodSeaPeakFightAttackItem_skin");
end

function Lua_GodSeaPeakFightAttackItem:buildShowItem()
	self:superCall("buildShowItem");
	self.heroList = Array();

	self.forceNum = Lua_NumberImage.new(self.content);
	self.forceNum:setLocation(-70, 0, 0);
	self.forceNum.pivot = 1;
	self.forceNum.scaleVal = 0.9;
	self.forceNum.numOffsetX = -2;
	self.forceNum.numAtlas = "number";
	self.forceNum.preStr = "xui_zl1_number_0";

	self.btnEdit:addClickFuntion(self, self.onEditClick);
end

function Lua_GodSeaPeakFightAttackItem:dispose()
	if self.heroList then
		self.heroList:dispose();
		self.heroList:clear();
		self.heroList = nil;
	end
	if self.forceNum then
		self.forceNum:dispose();
		self.forceNum = nil;
	end
	self:superCall("dispose");
end

function Lua_GodSeaPeakFightAttackItem:setData(idx, data)
	self.lineupIdx = idx;
	self.numText.text = idx;

	local arr = Array();
	for i = 1, data:getSize() do
		if data[i] > 0 then
			arr:add(data[i]);
		end
	end

	local num = idx * 2;
	local len = self.heroList:getSize();
	local maxLen = num > len and num or len;
	local item, vo;
	local force = 0;
	for i = 1, maxLen do
		item = self.heroList[i];
		if i > num then
			if item then
				item:setEnable(false);
			end
		else
			if item == nil then
				item = Lua_ItemIcon.new(self.content);
				item:setCanClick(true);
				item:setScale(0.5, 0.5, 1);
				self.heroList:add(item);
			else
				item:setEnable(true);
			end
			if num == 2 then
				item:setLocation(-35 + (i - 1) * 65, -100, 0);
			elseif num == 4 then
				if i == 1 then
					item:setLocation(0, -67.5, 0);
				else
					item:setLocation(-130 + (i - 1) * 65, -132.5, 0);
				end
			else
				if i < 4 then
					item:setLocation(-65 + (i - 1) * 65, -67.5, 0);
				else
					item:setLocation(-260 + (i - 1) * 65, -132.5, 0);
				end
			end

			vo = DataCenter.heroLineupData:getHeroVo(i, arr[i]);
			if vo then
				force = force + vo.heroForce;
			end
			item:setData(vo);
		end
	end
	self.forceNum.num = force;
end

function Lua_GodSeaPeakFightAttackItem:onEditClick(go)
	Lua_MsgUtil.callFunc("GOD_SEA_PEAK_LINEUP", self.lineupIdx);
end