Lua_GodSeaPeakMatchWindow = class("Lua_GodSeaPeakMatchWindow", Lua_Window)
function Lua_GodSeaPeakMatchWindow:ctor()
	self:superCall("ctor");

	self.layer = MainWinDefine.NORMAL_WINDOW_LAYER;
	self.windowName = "Lua_GodSeaPeakMatchWindow";
	self.skinName = "GodSeaPeakMatchWindow_skin";
	self.showWinBg = true;
	self.isFullSizeWin = true;
	self.showBackBtn = true;

	self.winBgPath = "/images/god_sea_peak/xui_shzd_bg_2.jpg";
	self:addPreLoadRes(self.winBgPath, Lua_LoadFileType.IMG);
end

function Lua_GodSeaPeakMatchWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.winBg.anchorValue = 4;
	self.winBg.pivotValue = 4;
	self.itemList = Array();

	self:addLuaEvent("UPDATE_HERO_LINEUP_INFO", self, self.onLineupInfoUpdate);
	self:addLuaEvent("GOD_SEA_PEAK_FIGHT_TIMES", self, self.updateFightTimes);
	self:addLuaEvent("GOD_SEA_PEAK_MATCH_INFO", self, self.updateShowInfo);

	self.roleInfoPanel = Lua_RoleInfoPanel.new(self.content);
	self.roleInfoPanel:setRectAnchor(1);

	self.bgEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_shzd_hm", "ui_shzd_hm", 0, -380);
	self.bgEff.siblingIndex = 1;

	self.uiEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/shenhai_blueship", "shenhai_blueship", -118, 178);
	self.uiEff.siblingIndex = 2;
	self.uiEff.anchorValue = 7;

	self.forceNum = Lua_NumberImage.new(self.content);
	self.forceNum:setRectAnchor(7);
	self.forceNum:setLocation(-129, 150, 0);
	self.forceNum.scaleVal = 0.9;
	self.forceNum.numOffsetX = -2;
	self.forceNum.numAtlas = "number";
	self.forceNum.firstStr = "xui_zl1_number_10";
	self.forceNum.preStr = "xui_zl1_number_0";

	self.checkHelp:addClickFuntion(self, self.onCheckHelp);
	self.btnMatch:addClickFuntion(self, self.onMatchClick);
	self.selfImg:addClickFuntion(self, self.onLineup);
    self.timesAdd:addClickFuntion(self, self.onAddFightTimes);

    self:onLineupInfoUpdate();
    self:updateFightTimes();
    self:updateCoolTimer();
    Lua_ProxyManager.getProxy("Lua_GodSeaPeakProxy"):sMatchInfo(2);
end

function Lua_GodSeaPeakMatchWindow:dispose()
	self:stopTimer();
	if self.bgEff then
		self.bgEff:dispose();
		self.bgEff = nil;
	end
	if self.uiEff then
		self.uiEff:dispose();
		self.uiEff = nil;
	end
	if self.itemList then
		self.itemList:dispose();
		self.itemList:clear();
		self.itemList = nil;
	end
	if self.roleInfoPanel then
		self.roleInfoPanel:dispose();
		self.roleInfoPanel = nil;
	end
	if self.forceNum then
		self.forceNum:dispose();
		self.forceNum = nil;
	end
	DataCenter.preLoadData:removeBySign("Lua_GodSeaPeakLineupWindow", self, self.onSceneShow);
	DataCenter.winTweenManager:removeWinTween(self.tweenName);
	self.tweenName = nil;
	self:superCall("dispose");
end

function Lua_GodSeaPeakMatchWindow:onLineupInfoUpdate(lineupType)
	self.ownForce = 0;
	for i = 1, 3 do
		self.ownForce = self.ownForce + DataCenter.heroLineupData:calcLineupForce(59, i);
	end
	self.forceNum.num = self.ownForce;

	for i = 1, self.itemList:getSize() do
		self.itemList[i]:updateData(self.ownForce);
	end
end

function Lua_GodSeaPeakMatchWindow:updateFightTimes()
	self.timesText.text = LanUtil.formateStr(790007, tostring(DataCenter.godSeaPeakData.leftFightTimes));
end

function Lua_GodSeaPeakMatchWindow:updateShowInfo(msg)
	local item;
	local dataLen = msg.adversary_data and #msg.adversary_data or 0;
	local len = self.itemList:getSize();
	local maxLen = dataLen > len and dataLen or len;
	for i = 1, maxLen do
		item = self.itemList[i];
		if i > dataLen then
			if item then
				item:setEnable(false);
			end
		else
			if item == nil then
				item = Lua_GodSeaPeakMatchItem.new(self.content);
				self.itemList:add(item);
			else
				item:setEnable(true);
			end
			item.contentName = "Lua_GodSeaPeakMatchItem"..i;
			item:setLocation(-200 + ((i - 1) % 2) * 380, 300 + Mathf.Floor((i - 1) / 2) * -376, 0);
			item:setData(msg.adversary_data[i], self.ownForce);
		end
	end
	self:updateFightTimes();

	DataCenter.winTweenManager:removeWinTween(self.tweenName);
	self.tweenName = DataCenter.winTweenManager:createWinTween("GodSeaPeakMatch", self.content.transform);
end

function Lua_GodSeaPeakMatchWindow:onCheckHelp(go)
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, { des = 790015, posX = 160, posY = -290 });
end

function Lua_GodSeaPeakMatchWindow:onMatchClick(go)
	if self.bCool then
		OperateAlert.showLangValue(790033);
		return;
	end

	Lua_ProxyManager.getProxy("Lua_GodSeaPeakProxy"):sMatchInfo(1);
	DataCenter.godSeaPeakData.matchCoolTime = getTime() + DataCenter.godSeaPeakUtil.matchTick;
	self:updateCoolTimer();
end

function Lua_GodSeaPeakMatchWindow:updateCoolTimer()
	if DataCenter.godSeaPeakData.matchCoolTime == nil then
		return;
	end
	self:startTimer();
	self:onTimer();
end

function Lua_GodSeaPeakMatchWindow:startTimer()
	if self.bTimer ~= true then
		self.bTimer = true;
		self:addTimer("Lua_GodSeaPeakMatchWindow", 1, self, self.onTimer, nil, -1);
	end
end

function Lua_GodSeaPeakMatchWindow:stopTimer()
	if self.bTimer == true then
		self.bTimer = false;
		self:removeTimer(self, self.onTimer);
	end
end

function Lua_GodSeaPeakMatchWindow:onTimer()
	local value = Mathf.Ceil(DataCenter.godSeaPeakData.matchCoolTime - getTime());
	if value > 0 then
		self.bCool = true;
		self.matchLabel.text = LanUtil.formateStr(790016, tostring(value));
	else
		self:stopTimer();
		self.bCool = false;
		self.matchLabel:setLangValue(790017);
	end
end

function Lua_GodSeaPeakMatchWindow:onLineup(go)
	local sceneId = DataCenter.heroLineupData:getFightLineupSceneId(Lua_FightDefine.TEMPLATE_ID_GODSEAPEAK);
	DataCenter.preLoadData:preShowScene("Lua_GodSeaPeakLineupWindow", Lua_PreLoadDefine.LOADSHOW_TYPE_NONE, self, self.onSceneShow, idx, sceneId, 0);
end

function Lua_GodSeaPeakMatchWindow:onSceneShow(param, mp, success)
	if not success then return; end
	Lua_WindowUtil.openWin("Lua_GodSeaPeakLineupWindow", Lua_WinParam.ACTION_OPEN, 59);
end

function Lua_GodSeaPeakMatchWindow:onAddFightTimes(go)
	if DataCenter.godSeaPeakData.acquiredState == 1 then
		OperateAlert.showLangValue(790044);
		return;
	end
	Lua_WindowUtil.openWin("Lua_GodSeaPeakBuyTimesWindow", Lua_WinParam.ACTION_OPEN);
end










Lua_GodSeaPeakMatchItem = class("Lua_GodSeaPeakMatchItem", Lua_DisplayObject)
function Lua_GodSeaPeakMatchItem:ctor(p)
	self:superCall("ctor", p, "GodSeaPeakMatchItem_skin");
end

function Lua_GodSeaPeakMatchItem:buildShowItem()
	self:superCall("buildShowItem");
	self.uiEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/shenhai_redship", "shenhai_redship", 20, -63);
	self.uiEff.siblingIndex = 0;

	self.avatarItem = Lua_AvatarItem.new(self.content);
	self.avatarItem:setScale(0.4, 0.4, 1);
	self.avatarItem:setLocation(-120, 143, 0);

	self.btnCheck:addClickFuntion(self, self.onCheckClick);
	self.btnFight:addClickFuntion(self, self.onFightClick);

	Lua_CommonUtil.delayCall(Mathf.Random(1, 3), self, self.onPlayEff);
end

function Lua_GodSeaPeakMatchItem:dispose()
	Lua_CommonUtil.removeTimer(self, self.onPlayEff);
	if self.uiEff then
		self.uiEff:dispose();
		self.uiEff = nil;
	end
	if self.avatarItem then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_GodSeaPeakMatchItem:onPlayEff()
	self.uiEff:setSpineAniState(0, "wait");
end

function Lua_GodSeaPeakMatchItem:setData(data, ownForce)
	self.data = data;

	self.avatarItem:setRoleDressUp(data.show_role.dress_info);
	if data.is_robot == 1 then
		self.nameText.text = data.show_role.name;
	else
		self.nameText.text = LanUtil.formateStr(10051, data.show_role.server_prev, data.show_role.name);
	end
	self.scoreText.text = LanUtil.formateStr(790037, tostring(data.score));
	self.winScoreText.text = LanUtil.formateStr(10049, tostring(data.win_score));

	self:updateData(ownForce);
end

function Lua_GodSeaPeakMatchItem:updateData(ownForce)
	if self.data.fighting > ownForce * DataCenter.godSeaPeakUtil.forceRate then
		self.forceText.colorStr = Lua_ColorDefine.transColor("FF6363");
	else
		self.forceText.colorStr = Lua_ColorDefine.transColor("FFE27F");
	end
	self.forceText.text = LanUtil.formateStr(790038, tostring(self.data.fighting));
end

function Lua_GodSeaPeakMatchItem:onCheckClick(go)
	Lua_WindowUtil.openWin("Lua_GodSeaPeakEnemyWindow", Lua_WinParam.ACTION_OPEN, self.data);
end

function Lua_GodSeaPeakMatchItem:onFightClick(go)
	if DataCenter.godSeaPeakData.acquiredState == 1 then
		OperateAlert.showLangValue(790043);
		return;
	end

	if DataCenter.godSeaPeakData.leftFightTimes > 0 then
		Lua_WindowUtil.openWin("Lua_GodSeaPeakFightWindow", Lua_WinParam.ACTION_OPEN, self.data);
	elseif DataCenter.godSeaPeakData.leftBuyTimes > 0 then
		Lua_WindowUtil.openWin("Lua_GodSeaPeakBuyTimesWindow", Lua_WinParam.ACTION_OPEN);
	else
		OperateAlert.showLangValue(790027);
	end
end