Lua_GodSeaPeakRecordDetailsWindow = class("Lua_GodSeaPeakRecordDetailsWindow", Lua_Window)
function Lua_GodSeaPeakRecordDetailsWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_GodSeaPeakRecordDetailsWindow";
	self.skinName = "GodSeaPeakRecordDetailsWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_GodSeaPeakRecordDetailsWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.itemList = Lua_DragList.new(self.content, 652, 720, Lua_AxisDefine.Vertical);
	self.itemList:setLocation(0, -70, 0);
	self.itemList:setListCell(Lua_GodSeaPeakRecordDetailsItem, 652, 435, 1);

	self:addLuaEvent("GOD_SEA_PEAK_RECORD_DETAILS", self, self.updateShowInfo);
end

function Lua_GodSeaPeakRecordDetailsWindow:dispose()
	if self.itemList then
		self.itemList:dispose();
		self.itemList = nil;
	end
	self:superCall("dispose");
end

function Lua_GodSeaPeakRecordDetailsWindow:showWin(param)
	self:superCall("showWin", param);
	Lua_ProxyManager.getProxy("Lua_GodSeaPeakProxy"):sRecordDetails(param.fight_record_id);

	-- 1己方为进攻方 2己方为防守方
	if param.self_pos == 1 then
		self.leftName.text = param.self_name;
		if param.is_robot == 1 then
			self.rightName.text = param.fighter_name;
		else
			self.rightName.text = LanUtil.formateStr(10066, param.server_prev, param.fighter_name);
		end
	else
		if param.is_robot == 1 then
			self.leftName.text = param.fighter_name;
		else
			self.leftName.text = LanUtil.formateStr(10066, param.server_prev, param.fighter_name);
		end
		self.rightName.text = param.self_name;
	end
end

function Lua_GodSeaPeakRecordDetailsWindow:updateShowInfo(msg)
	self.resultText.text = LanUtil.formateStr(10050, tostring(msg.att_num), tostring(msg.def_num));

	local arr = Array();
	local data = msg.fight_report_info;
	local len = data == nil and 0 or #data;
	if len > 1 then
		table.sort(data, function(a, b) return a.rotation < b.rotation end);
	end
	local canDrag = true;
	for i = 1, len do
		if len >= i then
			arr:add({ index = i, info = self.showData, data = data[i] });
		else
			canDrag = false;
			arr:add({ index = i, info = self.showData, data = nil });
		end
	end
	self.itemList:setArrayData(arr);
	self.itemList.canDrag = canDrag;
end










Lua_GodSeaPeakRecordDetailsItem = class("Lua_GodSeaPeakRecordDetailsItem", Lua_ListCell)
function Lua_GodSeaPeakRecordDetailsItem:ctor(p)
	self:superCall("ctor", p, "GodSeaPeakRecordDetailsItem_skin");
end

function Lua_GodSeaPeakRecordDetailsItem:buildShowItem()
	self:superCall("buildShowItem")

	self.leftAvatar = Lua_AvatarItem.new(self.showObject);
	self.leftAvatar:setSiblingIndex(1);
	self.leftAvatar:setScale(0.4, 0.4, 1);
	self.leftAvatar:setLocation(-290, 140, 0);
	self.leftAvatar:setRoleAvatar(0);

	self.rightAvatar = Lua_AvatarItem.new(self.showObject);
	self.rightAvatar:setSiblingIndex(2);
	self.rightAvatar:setScale(0.4, 0.4, 1);
	self.rightAvatar:setLocation(290, 140, 0);
	self.rightAvatar:setRoleAvatar(0);

	self.leftPanel = Lua_HeroGridViewPanel.new(self.showObject);
	self.leftPanel:setLocation(-170, -35, 0);
	self.leftPanel:setLayout(1, 2);
	self.leftPanel:setGridCell(70, 70, Lua_TimeSpaceFightDetailsGridItem);
	self.leftPanel:setCanClick(true);

	self.rightPanel = Lua_HeroGridViewPanel.new(self.rightObject);
	self.rightPanel:setLocation(170, -35, 0);
	self.rightPanel:setLayout(1, 0);
	self.rightPanel:setGridCell(70, 70, Lua_TimeSpaceFightDetailsGridItem);
	self.rightPanel:setCanClick(true);

	self.noneText:setEnable(false);
	self.btnPlay:addClickFuntion(self, self.onPlay);
	self.checkHurt:addClickFuntion(self, self.onCheckHurt);
end

function Lua_GodSeaPeakRecordDetailsItem:dispose()
	if self.leftAvatar then
		self.leftAvatar:dispose();
		self.leftAvatar = nil;
	end
	if self.rightAvatar then
		self.rightAvatar:dispose();
		self.rightAvatar = nil;
	end
	if self.leftPanel then
		self.leftPanel:dispose();
		self.leftPanel = nil;
	end
	if self.rightPanel then
		self.rightPanel:dispose();
		self.rightPanel = nil;
	end
	self.data = nil;
	self:superCall("dispose")
end

function Lua_GodSeaPeakRecordDetailsItem:setData(data)
	self.data = data
	if data.data == nil then
		self.showObject:SetActive(false);
		self.noneText:setEnable(true);
		self.noneText.text = LanUtil.formateStr(770011, convert_arab_to_chinese(data.index));
	else
		self.showObject:SetActive(true);
		self.noneText:setEnable(false);

		local info = data.info;
		local msg = data.data;

		local maxRound = Lua_FightTemplateConfigData.getConfigData(Lua_FightDefine.TEMPLATE_ID_PEAKDUEL).maxRound;
		self.show_round.text = LanUtil.formateStr(10044, tostring(msg.round), tostring(maxRound));
		self.match_time.text = os.date("%Y-%m-%d %H:%M", tonumber(info.tick));

		if msg.win_id == 1 then
			self.left_result:setAltas("common_altas_4", "xui_jys_label_1");
			self.right_result:setAltas("common_altas_4", "xui_jys_label_2");
		else
			self.left_result:setAltas("common_altas_4", "xui_jys_label_2");
			self.right_result:setAltas("common_altas_4", "xui_jys_label_1");
		end

		-- 1己方为进攻方 2己方为防守方
		if info.self_pos == 1 then
			self.leftAvatar:setRoleDressUp(info.self_dress_info);
			self.left_name.text = info.self_name;
			
			self.rightAvatar:setRoleDressUp(info.fighter_dress_info);
			if info.is_robot == 1 then
				self.right_name.text = info.fighter_name;
			else
				self.right_name.text = LanUtil.formateStr(10066, info.server_prev, info.fighter_name);
			end
		else
			self.leftAvatar:setRoleDressUp(info.fighter_dress_info);
			if info.is_robot == 1 then
				self.left_name.text = info.fighter_name;
			else
				self.left_name.text = LanUtil.formateStr(10066, info.server_prev, info.fighter_name);
			end

			self.rightAvatar:setRoleDressUp(info.self_dress_info);
			self.right_name.text = info.self_name;
		end

		self.left_team.text = LanUtil.formateStr(202955, tostring(msg.att_index));
		self.left_force.text = msg.att_force;
		self.leftPanel:setDataByProto(msg.att_lineup);

		self.left_bar:setMaxValue(100);
		self.left_bar:setValue(msg.att_health);
		self.left_bar:setText(LanUtil.formateStr(10057, tostring(msg.att_health)));

		self.right_team.text = LanUtil.formateStr(202955, tostring(msg.def_index));
		if msg.def_lineup and #msg.def_lineup > 0 then
			self.rightObject:SetActive(true);
			self.rightNoneText:setEnable(false);

			self.right_force.text = msg.def_force;
			self.right_force:resetSize();
			self.rightForceIcon:setLocation(315 - self.right_force.width - 5, -193, 0);
			self.rightPanel:setDataByProto(msg.def_lineup);

			self.right_bar:setMaxValue(100);
			self.right_bar:setValue(msg.def_health);
			self.right_bar:setText(LanUtil.formateStr(10057, tostring(msg.def_health)));
		else
			self.rightObject:SetActive(false);
			self.rightNoneText:setEnable(true);
		end
	end
end

function Lua_GodSeaPeakRecordDetailsItem:onPlay(go)
	if self.data == nil or self.data.data == nil then
		return
	end
	local data = self.data.data;
	if data.def_lineup == nil and #data.def_lineup < 0 then
		OperateAlert.show(LanUtil.formateStr(770011, convert_arab_to_chinese(data.def_index)));
		return;
	end
	Lua_ProxyManager.getProxy("Lua_FightProxy"):sFightReplay(data.record_id, 0, "", data.rotation, 14);
end

function Lua_GodSeaPeakRecordDetailsItem:onCheckHurt(go)
	if self.data == nil or self.data.data == nil then
		return
	end
	local data = self.data.data;
	if data.def_lineup == nil and #data.def_lineup < 0 then
		OperateAlert.show(LanUtil.formateStr(770011, convert_arab_to_chinese(data.def_index)));
		return;
	end
	Lua_ProxyManager.getProxy("Lua_FightProxy"):sFightHurtCollect(data.record_id, 14);
end










Lua_TimeSpaceFightDetailsGridItem = class("Lua_TimeSpaceFightDetailsGridItem", Lua_HeroGridViewItem)
function Lua_TimeSpaceFightDetailsGridItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_TimeSpaceFightDetailsGridItem:buildShowItem()
	self:superCall("buildShowItem");
	self.bg:setScale(0.9, 0.9, 1);
end

function Lua_TimeSpaceFightDetailsGridItem:setData(dataType, data)
	self:superCall("setData", dataType, data);
	if self.itemIcon then
		self.itemIcon:setScale(0.54, 0.54, 1);
	end
end