Lua_GodSeaPeakTreasurePanel = class("Lua_GodSeaPeakTreasurePanel", Lua_DisplayObject)
function Lua_GodSeaPeakTreasurePanel:ctor(p)
	self:superCall("ctor", p, "GodSeaPeakTreasurePanel_skin");
end

function Lua_GodSeaPeakTreasurePanel:buildShowItem()
	self:superCall("buildShowItem");
	self.luckBar.typeValue = 3;
	self.luckBar.fillMethodValue = 0;
	self.luckBar.fillOrigin = 0;
	self.luckBar:setMaxValue(1);
	self.luckBar:setValue(0);

	self.rewardList = Array();
	self.luckList = Array();

	local arr = DataCenter.godSeaPeakUtil.treasureList;
	local item;
	for i = 1, arr:getSize() do
		item = Lua_GodSeaPeakTreasureItem.new(self.bubbleObject);
		item:setData(arr[i]);
		self.rewardList:add(item);
	end

	self.ruleIcon:addClickFuntion(self, self.onCheckRule);
	self.btnOne:setLangValue(790045);
	self.btnOne:addClickFuntion(self, self.onOneClick);
	self.btnTen:setLangValue(790046);
	self.btnTen:addClickFuntion(self, self.onTenClick);
	self.recordBg:addClickFuntion(self, self.onCheckRecord);

	self:addLuaEvent("GOD_SEA_PEAK_TREASURE", self, self.updateShowInfo);
	self:addLuaEvent("WIN_SHOW_COMPLETE", self, self.onWinShowCompleted);
	Lua_ProxyManager.getProxy("Lua_GodSeaPeakProxy"):sTreasureInfo();
	DataCenter.redPointData:updateRedPointState(Lua_RedPointList.GodSeaPeak_Treasure_Draw, false, true);
end

function Lua_GodSeaPeakTreasurePanel:dispose()
	Lua_CommonUtil.removeTimer(self, self.onDelayDraw);
	if self.rewardList then
		self.rewardList:dispose();
		self.rewardList:clear();
		self.rewardList = nil;
	end
	if self.luckList then
		self.luckList:dispose();
		self.luckList:clear();
		self.luckList = nil;
	end
	if self.oneRed then
		self.oneRed:dispose();
		self.oneRed = nil;
	end
	if self.tenRed then
		self.tenRed:dispose();
		self.tenRed = nil;
	end
	self:superCall("dispose");
end

function Lua_GodSeaPeakTreasurePanel:updateShowInfo(msg)
	local curLuck = msg.luck_point;
	local curLevel = msg.level_of_luck;
	local receivedDic = {}; -- 已领取
	for i,v in ipairs(msg.reward_list) do
		receivedDic[v] = 1;
	end

	self.luckText.text = curLuck;
	self.luckLvText.text = LanUtil.formateStr(10044, tostring(curLevel), tostring(DataCenter.godSeaPeakUtil.drawMaxLevel));

	local arr;
	local len;
	-- for i = 1, curLevel - 1 do
	-- 	arr = DataCenter.godSeaPeakUtil:getDrawRewardByLv(i);
	-- 	len = arr:getSize();
	-- 	curLuck = curLuck - self:getLuckValue(arr[len]);
	-- end

	arr = DataCenter.godSeaPeakUtil:getDrawRewardByLv(curLevel);
	len = arr:getSize();

	local maxValue = self:getLuckValue(arr[len]);
	local value = 0;
	local index = 1;
	local curVal;
	local prevVal;
	if curLuck >= maxValue then
		value = maxValue;
	else
		local stepSpace = maxValue / len;
		for i = 1, len do
			curVal = self:getLuckValue(arr[i]);
			if curVal >= curLuck then
				index = i;
				break;
			end
		end
		value = value + stepSpace * (index - 1);
		local num;
		if index <= 1 then
			curVal = self:getLuckValue(arr[index]);
			num = stepSpace / curVal;
			value = value + curLuck * num;
		else
			prevVal = self:getLuckValue(arr[index - 1]);
			num = stepSpace / (curVal - prevVal);
			value = value + (curLuck - prevVal) * num;
		end
	end
	self.luckBar:setMaxValue(maxValue);
	self.luckBar:setValue(value);

	local num = self.luckList:getSize();
	local maxLen = len > num and len or num;
	for i = 1, maxLen do
		item = self.luckList[i];
		if i > len then
			if item then
				item:setEnable(false);
			end
		else
			if item == nil then
				item = Lua_GodSeaPeakTreasureLuckItem.new(self.content);
				self.luckList:add(item);
			else
				item:setEnable(true);
			end
			item:setRectAnchor(1);
			item:setLocation(i / len * 526 - 263, -163.5, 0);
			item:setData(i == len, arr[i], msg.luck_point, receivedDic);
		end
	end

	local cost = DataCenter.godSeaPeakUtil.oneDrawCost;
	self.oneCostId = cost[1];

	local config = getConfig("item", self.oneCostId);
	self.costIcon_1:setAltas(config.atlas, config.sprite);
	self.costText_1.text = cost[2];

	local hasCount = DataCenter.packData:getItemCountById(self.oneCostId);
	self.oneCostEnough = hasCount >= cost[2];

	cost = DataCenter.godSeaPeakUtil.tenDrawCost;
	self.tenCostId = cost[1];

	config = getConfig("item", self.tenCostId);
	self.costIcon_2:setAltas(config.atlas, config.sprite);
	self.costText_2.text = cost[2];

	hasCount = DataCenter.packData:getItemCountById(self.tenCostId);
	self.tenCostEnough = hasCount >= cost[2];
	

	config = getConfig("item", tonumber(tostring(msg.record_list.item_id)));
	if config == nil then
		self.recordText.text = nil;
	else
		local str = Lua_ColorDefine.getItemColorStr(config.color);
		str = Lua_ColorDefine.getColorStr(str, config.name);
		self.recordText.text = LanUtil.formateStr(790022, msg.record_list.player_name, str, tostring(msg.record_list.amount));
	end
	self.recordText:resetSize();

	local posX = self.recordText.width / 2;
	posX = posX == 0 and 192 or posX + 40;
	self.checkText:setLocation(posX, 140, 0);

	self:updateRedPoint();
end

function Lua_GodSeaPeakTreasurePanel:getLuckValue(id)
	return getConfig("god_sea_award", id, "luck_point") or 0;
end

function Lua_GodSeaPeakTreasurePanel:updateRedPoint()
	if self.oneCostEnough then
		if self.oneRed == nil then
			self.oneRed = Lua_RedPointIcon.new(self.content);
			self.oneRed:setRectAnchor(7);
			self.oneRed:setLocation(-75, 280, 0);
			self.oneRed:createRedPointEff();
		end
		self.oneRed:updateRedPointShow(true);
	else
		if self.oneRed then
			self.oneRed:updateRedPointShow(false);
		end
	end

	if self.tenCostEnough then
		if self.tenRed == nil then
			self.tenRed = Lua_RedPointIcon.new(self.content);
			self.tenRed:setRectAnchor(7);
			self.tenRed:setLocation(285, 280, 0);
			self.tenRed:createRedPointEff();
		end
		self.tenRed:updateRedPointShow(true);
	else
		if self.tenRed then
			self.tenRed:updateRedPointShow(false);
		end
	end
end

function Lua_GodSeaPeakTreasurePanel:onCheckRule(go)
	Lua_WindowUtil.openWin("Lua_GodSeaPeakTreasureRuleWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_GodSeaPeakTreasurePanel:onOneClick(go)
	if self.clickTime and getTime() - self.clickTime < 0.5 then
		OperateAlert.showLangValue(10031);
		return;
	end
	self.clickTime = getTime();

	if not self.oneCostEnough then
		DataCenter.packUtil:openPathWindow(self.oneCostId, false);
		return;
	end

	self:playDrawEff(1);
end

function Lua_GodSeaPeakTreasurePanel:onTenClick(go)
	if self.clickTime and getTime() - self.clickTime < 0.5 then
		OperateAlert.showLangValue(10031);
		return;
	end
	self.clickTime = getTime();

	if not self.tenCostEnough then
		DataCenter.packUtil:openPathWindow(self.tenCostId, false);
		return;
	end

	self:playDrawEff(10);
end

function Lua_GodSeaPeakTreasurePanel:playDrawEff(key)
	self.bubbleObject:SetActive(false);
	Lua_MsgUtil.callFunc("GOD_SEA_PEAK_TREASURE_DRAW", true);
	Lua_CommonUtil.removeTimer(self, self.onDelayDraw);
	Lua_CommonUtil.delayCall(60 / 30, self, self.onDelayDraw, key); -- 100帧
end

function Lua_GodSeaPeakTreasurePanel:onDelayDraw(key)
	Lua_ProxyManager.getProxy("Lua_GodSeaPeakProxy"):sTreasureDraw(key);
end

function Lua_GodSeaPeakTreasurePanel:onWinShowCompleted(winName)
	Lua_MsgUtil.callFunc("GOD_SEA_PEAK_TREASURE_DRAW", false);
	self.bubbleObject:SetActive(true);
end

function Lua_GodSeaPeakTreasurePanel:onCheckRecord(go)
	Lua_WindowUtil.openWin("Lua_GodSeaPeakTreasureRecordWindow", Lua_WinParam.ACTION_OPEN);
end









Lua_GodSeaPeakTreasureItem = class("Lua_GodSeaPeakTreasureItem", Lua_DisplayObject)
function Lua_GodSeaPeakTreasureItem:ctor(p)
	self:superCall("ctor", p, "GodSeaPeakTreasureItem_skin");
end

function Lua_GodSeaPeakTreasureItem:buildShowItem()
	self:superCall("buildShowItem");
	self.bg:addClickFuntion(self, self.onClick);
end

function Lua_GodSeaPeakTreasureItem:dispose()
	-- if self.tween then
	-- 	self.tween:Kill(false);
	-- 	self.tween = nil;
	-- end
	self:stopTween();
	self:superCall("dispose");
end

function Lua_GodSeaPeakTreasureItem:setData(data)
	local config = DataCenter.godSeaPeakUtil:getTreasureConfig(data);
	self.showX = config.show_pos[1] or 0;
	self.showY = config.show_pos[2] or 0;
	self:setLocation(self.showX, self.showY, 0);

	if config.color == 6 then
		self.bg:setAltas("god_sea_peak_atlas_2", "xui_shzd_widget_33");
		self.countText.effectColorStr = Lua_ColorDefine.transColor("4D1717");
	elseif config.color == 5 then
		self.bg:setAltas("god_sea_peak_atlas_2", "xui_shzd_widget_34");
		self.countText.effectColorStr = Lua_ColorDefine.transColor("56391B");
	elseif config.color == 4 then
		self.bg:setAltas("god_sea_peak_atlas_2", "xui_shzd_widget_35");
		self.countText.effectColorStr = Lua_ColorDefine.transColor("4D3A80");
	elseif config.color == 3 then
		self.bg:setAltas("god_sea_peak_atlas_2", "xui_shzd_widget_36");
		self.countText.effectColorStr = Lua_ColorDefine.transColor("1C4C69");
	elseif config.color == 2 then
		self.bg:setAltas("god_sea_peak_atlas_2", "xui_shzd_widget_37");
		self.countText.effectColorStr = Lua_ColorDefine.transColor("245640");
	else
		self.bg:setAltas("god_sea_peak_atlas_2", "xui_shzd_widget_37");
		self.countText.effectColorStr = Lua_ColorDefine.transColor("FFFFFF");
	end
	self.bg:resetSize();
	self:setRectSize(self.bg.width, self.bg.height);
	self.countText.text = config.show_reward[2];

	self.rewardId = config.show_reward[1];
	config = getConfig("item", self.rewardId);
	self.icon:setAltas(config.atlas, config.sprite);
	if config.color < 4 then
		self.icon:setScale(0.9, 0.9, 1);
	else
		self.icon:setScale(1, 1, 1);
	end

	-- if self.tween == nil then
	-- 	local value = LuaUtil.randomTriangle(1, 2);
	-- 	value = string.format("%.2f", value);
	-- 	self.tween = self.mainContent.transform:DOLocalMove(Vector3(self.showX, self.showY + 10, 0), value, false)
	-- 		:SetEase(DG.Tweening.Ease.InSine)
	-- 		:SetLoops(-1, DG.Tweening.LoopType.Yoyo)
	-- 		:SetUpdate(true);
	-- end
	self:stopTween();
	self:startTween();
end

function Lua_GodSeaPeakTreasureItem:startTween()
	self.startTime = getTime();
	self.tweenValue = string.format("%.2f", LuaUtil.randomTriangle(1, 3));
	self:addTimer("Lua_GodSeaPeakTreasureItem", 0.01, self, self.onTween, nil, -1, true);
end

function Lua_GodSeaPeakTreasureItem:stopTween()
	self:removeTimer(self, self.onTween);
end

function Lua_GodSeaPeakTreasureItem:onTween()
	local pt = (getTime() - self.startTime) * self.tweenValue;
	LuaUtil.setObjPos(self.mainContent, self.showX, self.showY + Mathf.Sin(pt) * 5, 0);
end

function Lua_GodSeaPeakTreasureItem:onClick(go)
	DataCenter.packUtil:showItemInfo(self.rewardId);
end










Lua_GodSeaPeakTreasureLuckItem = class("Lua_GodSeaPeakTreasureLuckItem", Lua_DisplayObject)
function Lua_GodSeaPeakTreasureLuckItem:ctor(p)
	self:superCall("ctor", p, "GodSeaPeakTreasureLuckItem_skin");
end

function Lua_GodSeaPeakTreasureLuckItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemIcon = Lua_ItemIcon.new(self.content);
	self.itemIcon:setSiblingIndex(1);
	self.itemIcon:setClick(self, self.onClick);
end

function Lua_GodSeaPeakTreasureLuckItem:dispose()
	if self.itemIcon then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	if self.redPoint then
		self.redPoint:dispose();
		self.redPoint = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_GodSeaPeakTreasureLuckItem:setData(isFinal, data, curLuckValue, receivedDic)
	if isFinal then
		self.bg:setScale(0.5, 0.5, 1);
		self.bg:setLocation(0, 32, 0);
		self.stateIcon:setScale(0.5, 0.5, 1);
		self.stateIcon:setLocation(0, 32, 0);
		self.numText.fontSize = 18;
		self.numText:setLocation(27, 12, 0);
		self.itemIcon:setScale(0.5, 0.5, 1);
		self.itemIcon:setLocation(0, 32, 0);
	else
		self.bg:setScale(0.4, 0.4, 1);
		self.bg:setLocation(0, 26, 0);
		self.stateIcon:setScale(0.4, 0.4, 1);
		self.stateIcon:setLocation(0, 26, 0);
		self.numText.fontSize = 16;
		self.numText:setLocation(21, 12, 0);
		self.itemIcon:setScale(0.4, 0.4, 1);
		self.itemIcon:setLocation(0, 26, 0);
	end
	self.data = data;

	local config = DataCenter.godSeaPeakUtil:getRewardConfig(data);
	if self.rewardVo == nil then
		self.rewardVo = Lua_ToolVo.createToolVo(config.reward[1][1]);
	else
		self.rewardVo:setData(config.reward[1][1]);
	end
	self.itemIcon:setData(self.rewardVo);
	self.numText.text = config.reward[1][2];
	self.luckText.text = config.luck_point;

	if receivedDic[data] == 1 then
		self.state = 2;
		self.stateIcon:setEnable(false);
		self.itemIcon:setDrawMask(true);
	elseif curLuckValue >= config.luck_point then
		self.state = 1;
		self.stateIcon:setEnable(true);
		self.itemIcon:setDrawMask(false);
	else
		self.state = 0;
		self.stateIcon:setEnable(false);
		self.itemIcon:setDrawMask(false);
	end
	self:showRedPoint();
end

function Lua_GodSeaPeakTreasureLuckItem:showRedPoint()
	if self.state == 1 then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content);
			self.redPoint:setLocation(25, 45, 0);
			self.redPoint:createRedPointEff();
		end
		self.redPoint:updateRedPointShow(true);
	else
		if self.redPoint then
			self.redPoint:updateRedPointShow(false);
		end
	end
end

function Lua_GodSeaPeakTreasureLuckItem:onClick(data)
	if self.state == 1 then
		Lua_ProxyManager.getProxy("Lua_GodSeaPeakProxy"):sRewardReceive(3, self.data);
	else
		DataCenter.packUtil:showItemInfo(data);
	end
end